==> haskell-doctest-driver-gen-0.3.0.8-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-driver-gen
version:              0.3.0.8
visibility:           public
id:                   doctest-driver-gen-0.3.0.8-Bz8Rgi851p89HmesDI69Ty
key:                  doctest-driver-gen-0.3.0.8-Bz8Rgi851p89HmesDI69Ty
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2023
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  e26c55673b79bf7bbc4b7435dde4a2df
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.8-Bz8Rgi851p89HmesDI69Ty
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-driver-gen-0.3.0.8-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-driver-gen
version:              0.3.0.8
visibility:           public
id:                   doctest-driver-gen-0.3.0.8-1sM1qAisUlRLZ23XjnFi8l
key:                  doctest-driver-gen-0.3.0.8-1sM1qAisUlRLZ23XjnFi8l
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2023
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  6bafaa006c22b4f78b9c2f754ed14f52
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.8-1sM1qAisUlRLZ23XjnFi8l
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
